==> haskell-recv-0.1.0-51-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-recv.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 recv
version:              0.1.0
visibility:           public
id:                   recv-0.1.0-4oK9oFChptoCJwDzg60KU7
key:                  recv-0.1.0-4oK9oFChptoCJwDzg60KU7
license:              BSD-3-Clause
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             Efficient network recv
description:          Network recv based on buffer pools
category:             Network
abi:                  de36a7ae096a704d53c7f173ca034310
exposed:              True
exposed-modules:      Network.Socket.BufferPool
hidden-modules:
    Network.Socket.BufferPool.Buffer Network.Socket.BufferPool.Recv
    Network.Socket.BufferPool.Types Network.Socket.BufferPool.Windows

import-dirs:          /usr/lib/ghc-9.4.8/site-local/recv-0.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/recv-0.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/recv-0.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-recv
hs-libraries:         HSrecv-0.1.0-4oK9oFChptoCJwDzg60KU7
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    network-3.1.4.0-3dx8iLR4JM2HWvxqoL7m7K

haddock-interfaces:   /usr/share/doc/haskell-recv/html/recv.haddock
haddock-html:         /usr/share/doc/haskell-recv/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-recv-0.1.0-53-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-recv.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 recv
version:              0.1.0
visibility:           public
id:                   recv-0.1.0-73rMYyUjnVd8z1yEfBukTG
key:                  recv-0.1.0-73rMYyUjnVd8z1yEfBukTG
license:              BSD-3-Clause
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             Efficient network recv
description:          Network recv based on buffer pools
category:             Network
abi:                  f24aa8a4bbe3b91b55cdf24473d6c28b
exposed:              True
exposed-modules:      Network.Socket.BufferPool
hidden-modules:
    Network.Socket.BufferPool.Buffer Network.Socket.BufferPool.Recv
    Network.Socket.BufferPool.Types Network.Socket.BufferPool.Windows

import-dirs:          /usr/lib/ghc-9.4.8/site-local/recv-0.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/recv-0.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/recv-0.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-recv
hs-libraries:         HSrecv-0.1.0-73rMYyUjnVd8z1yEfBukTG
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    network-3.1.4.0-82nHJL6Luo48oDimrIyJyV

haddock-interfaces:   /usr/share/doc/haskell-recv/html/recv.haddock
haddock-html:         /usr/share/doc/haskell-recv/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
